.. image:: https://img.shields.io/badge/REBOUNDx-v3.3.1-green.svg?style=flat
    :target: https://reboundx.readthedocs.org
.. image:: https://badge.fury.io/py/reboundx.svg
    :target: https://badge.fury.io/py/reboundx
.. image:: https://travis-ci.org/dtamayo/reboundx.svg?branch=master
    :target: https://travis-ci.org/dtamayo/reboundx
.. image:: https://coveralls.io/repos/dtamayo/reboundx/badge.svg?branch=master&service=github 
    :target: https://coveralls.io/github/dtamayo/reboundx?branch=master
.. image:: https://img.shields.io/badge/license-GPL-green.svg?style=flat 
    :target: https://github.com/dtamayo/reboundx/blob/master/LICENSE
.. image:: https://readthedocs.org/projects/pip/badge/?version=latest
    :target: https://reboundx.readthedocs.org/
.. image:: https://img.shields.io/badge/arXiv-1908.05634-green.svg?style=flat 
    :target: https://arxiv.org/abs/1908.05634
.. image:: https://img.shields.io/badge/launch-binder-ff69b4.svg?style=flat
    :target: https://mybinder.org/repo/dtamayo/reboundx

Welcome to REBOUNDx (eXtras)
============================

REBOUNDx allows you to easily incorporate additional physics into your REBOUND simulations.
The main code is written in C, and we provide a convenient Python wrapper.
For an overview of the technical details and some practical recommendations, see `Tamayo, Rein, Shi and Hernandez 2019 <https://arxiv.org/abs/1908.05634>`_.
The paper publication lines up with REBOUNDx version 3.0.0.

Documentation
=============

For a list of supported effects, and descriptions of the parameters that need to be set for each effect, see the documentation at `https://reboundx.readthedocs.io <https://reboundx.readthedocs.io>`_.
You can also find installation instructions and a quickstart guide there.

Attribution
===========

We have tried to structure the documentation in a way that makes it easy to credit the various people who have contributed to any given effect.
Please see the Attribution section at `https://reboundx.readthedocs.io <https://reboundx.readthedocs.io>`_ for direct links to ADS.

Changelog
=========

Version 3.1.0
-------------

* Added interpolator object for interpolating parameters
* Many improvements to the documentation

Version 3.0.5
-------------

* Generalized tides_precession effect to general constant time lag model (Hut 1981)
